pub enum NodeHash {
Hashed(H256),
Inline(([u8; 31], u8)),
}Expand description
Struct representing a trie node hash If the encoded node is less than 32 bits, contains the encoded node itself
Variants
Implementations
Sourceimpl NodeHash
impl NodeHash
Sourcepub fn from_encoded(encoded: &[u8], crypto: &dyn Crypto) -> NodeHash
pub fn from_encoded(encoded: &[u8], crypto: &dyn Crypto) -> NodeHash
Returns the NodeHash of an encoded node (encoded using the NodeEncoder)
Sourcepub fn finalize(self, crypto: &dyn Crypto) -> H256
pub fn finalize(self, crypto: &dyn Crypto) -> H256
Returns the finalized hash NOTE: This will hash smaller nodes, only use to get the final root hash, not for intermediate node hashes
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Returns true if the hash is valid The hash will only be considered invalid if it is empty Aka if it has a default value instead of being a product of hash computation
Sourcepub fn encode<'a>(&self, encoder: Encoder<'a>) -> Encoder<'a>
pub fn encode<'a>(&self, encoder: Encoder<'a>) -> Encoder<'a>
Encodes this NodeHash with the given encoder.
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool