Node

Enum Node 

pub enum Node {
    Branch(Box<BranchNode>),
    Extension(ExtensionNode),
    Leaf(LeafNode),
}
A Node in an Ethereum Compatible Patricia Merkle Trie

Variants



Branch(Box<BranchNode>)



Extension(ExtensionNode)



Leaf(LeafNode)

Implementations

Source

impl Node

pub fn get( &self, db: &dyn TrieDB, path: Nibbles, ) -> Result<Option<ValueRLP>, TrieError>

Retrieves a value from the subtrie originating from this node given its path

pub fn insert( &mut self, db: &dyn TrieDB, path: Nibbles, value: impl Into<ValueOrHash>, ) -> Result<(), TrieError>

Inserts a value into the subtrie originating from this node.

pub fn remove( &mut self, db: &dyn TrieDB, path: Nibbles, ) -> Result<(bool, Option<ValueRLP>), TrieError>

Removes a value from the subtrie originating from this node given its path Returns a bool indicating if the new subtrie is empty, and the removed value if it existed in the subtrie

pub fn get_path( &self, db: &dyn TrieDB, path: Nibbles, node_path: &mut Vec<Vec<u8>>, ) -> Result<(), TrieError>

Traverses own subtrie until reaching the node containing path Appends all encoded nodes traversed to node_path (including self) Only nodes with encoded len over or equal to 32 bytes are included

pub fn compute_hash(&self, crypto: &dyn Crypto) -> NodeHash

Computes the node’s hash

pub fn compute_hash_no_alloc( &self, buf: &mut Vec<u8>, crypto: &dyn Crypto, ) -> NodeHash

Computes the node’s hash

pub fn memoize_hashes(&self, buf: &mut Vec<u8>, crypto: &dyn Crypto)

Recursively memoizes the hashes of all nodes of the subtrie that has self as root (post-order traversal)

pub fn encode_subtrie( &self, encoded: &mut Vec<NodeRLP>, ) -> Result<(), TrieError>

Recursively encodes all embedded nodes of the subtrie that has self as root.

This won’t encode nodes which are not embedded in self.