pub enum NodeRef {
Node(Arc<Node>, OnceLock<NodeHash>),
Hash(NodeHash),
}Expand description
A reference to a node.
Explicit rkyv bounds are needed because this is a recursive type, whose bounds can’t be automatically resolved.
Variants
Node(Arc<Node>, OnceLock<NodeHash>)
The node is embedded within the reference.
Hash(NodeHash)
The node is in the database, referenced by its hash.
Implementations
Sourceimpl NodeRef
impl NodeRef
Sourcepub fn get_node(
&self,
db: &dyn TrieDB,
path: Nibbles,
) -> Result<Option<Arc<Node>>, TrieError>
pub fn get_node( &self, db: &dyn TrieDB, path: Nibbles, ) -> Result<Option<Arc<Node>>, TrieError>
Gets a shared reference to the inner node. Requires that the trie is in a consistent state, ie that all leaves being pointed are in the database. Outside of snapsync this should always be the case.
Sourcepub fn get_node_checked(
&self,
db: &dyn TrieDB,
path: Nibbles,
) -> Result<Option<Arc<Node>>, TrieError>
pub fn get_node_checked( &self, db: &dyn TrieDB, path: Nibbles, ) -> Result<Option<Arc<Node>>, TrieError>
Gets a shared reference to the inner node, checking its hash.
Returns Ok(None) if the hash is invalid.
Uses NativeCrypto directly because this function is only reachable from
native storage/sync paths (get_root_node, get_proof, validate,
verify_range, trie iterator) — never from the guest program path, which
traverses via Node::get().
pub fn is_valid(&self) -> bool
pub fn commit( &mut self, path: Nibbles, acc: &mut Vec<(Nibbles, Vec<u8>)>, crypto: &dyn Crypto, ) -> NodeHash
pub fn compute_hash(&self, crypto: &dyn Crypto) -> NodeHash
pub fn compute_hash_ref(&self, crypto: &dyn Crypto) -> &NodeHash
pub fn compute_hash_no_alloc( &self, buf: &mut Vec<u8>, crypto: &dyn Crypto, ) -> &NodeHash
pub fn memoize_hashes(&self, buf: &mut Vec<u8>, crypto: &dyn Crypto)
Sourcepub fn clear_hash(&mut self)
pub fn clear_hash(&mut self)
Resets the memoized hash of this Node
This is used when mutating a node in place, in which case the memoized hash is not valid anymore.