pub struct BranchNode {
pub choices: [NodeRef; 16],
pub value: ValueRLP,
}Expand description
Branch Node of an an Ethereum Compatible Patricia Merkle Trie Contains the node’s value and the hash of its children nodes
Fields
choices: [NodeRef; 16]value: ValueRLPImplementations
Sourceimpl BranchNode
impl BranchNode
Sourcepub const EMPTY_CHOICES: [NodeRef; 16]
pub const EMPTY_CHOICES: [NodeRef; 16]
Empty choice array for more convenient node-building
Sourcepub fn new(choices: [NodeRef; 16]) -> Self
pub fn new(choices: [NodeRef; 16]) -> Self
Creates a new branch node given its children, without any stored value
Sourcepub const fn new_with_value(choices: [NodeRef; 16], value: ValueRLP) -> Self
pub const fn new_with_value(choices: [NodeRef; 16], value: ValueRLP) -> Self
Creates a new branch node given its children and value
Sourcepub fn get(
&self,
db: &dyn TrieDB,
path: Nibbles,
) -> Result<Option<ValueRLP>, TrieError>
pub fn get( &self, db: &dyn TrieDB, path: Nibbles, ) -> Result<Option<ValueRLP>, TrieError>
Retrieves a value from the subtrie originating from this node given its path
Sourcepub fn insert(
&mut self,
db: &dyn TrieDB,
path: Nibbles,
value: ValueOrHash,
) -> Result<(), TrieError>
pub fn insert( &mut self, db: &dyn TrieDB, path: Nibbles, value: ValueOrHash, ) -> Result<(), TrieError>
Inserts a value into the subtrie originating from this node
Sourcepub fn remove(
&mut self,
db: &dyn TrieDB,
path: Nibbles,
) -> Result<(Option<NodeRemoveResult>, Option<ValueRLP>), TrieError>
pub fn remove( &mut self, db: &dyn TrieDB, path: Nibbles, ) -> Result<(Option<NodeRemoveResult>, Option<ValueRLP>), TrieError>
Removes a value from the subtrie originating from this node given its path
Returns the new root of the subtrie (or a Mutated variant if the new root is self)
and the removed value if it existed in the subtrie.
Sourcepub fn compute_hash(&self, crypto: &dyn Crypto) -> NodeHash
pub fn compute_hash(&self, crypto: &dyn Crypto) -> NodeHash
Computes the node’s hash
Sourcepub fn compute_hash_no_alloc(
&self,
buf: &mut Vec<u8>,
crypto: &dyn Crypto,
) -> NodeHash
pub fn compute_hash_no_alloc( &self, buf: &mut Vec<u8>, crypto: &dyn Crypto, ) -> NodeHash
Computes the node’s hash, using the provided buffer
Sourcepub fn get_path(
&self,
db: &dyn TrieDB,
path: Nibbles,
node_path: &mut Vec<Vec<u8>>,
) -> Result<(), TrieError>
pub fn get_path( &self, db: &dyn TrieDB, path: Nibbles, node_path: &mut Vec<Vec<u8>>, ) -> Result<(), TrieError>
Traverses own subtrie until reaching the node containing path
Appends all encoded nodes traversed to node_path (including self)
Only nodes with encoded len over or equal to 32 bytes are included