ExtensionNode

Struct ExtensionNode 

pub struct ExtensionNode {
    pub prefix: Nibbles,
    pub child: NodeRef,
}
Extension Node of an an Ethereum Compatible Patricia Merkle Trie Contains the node’s prefix and a its child node hash, doesn’t store any value

Fields

prefix: Nibbleschild: NodeRef

Implementations

Source

impl ExtensionNode

pub const fn new(prefix: Nibbles, child: NodeRef) -> Self

Creates a new extension node given its child hash and prefix

pub fn get( &self, db: &dyn TrieDB, path: Nibbles, ) -> Result<Option<ValueRLP>, TrieError>

Retrieves a value from the subtrie originating from this node given its path

pub fn insert( &mut self, db: &dyn TrieDB, path: Nibbles, value: ValueOrHash, ) -> Result<Option<Node>, TrieError>

Inserts a value into the subtrie originating from this node and returns the new root of the subtrie. If the new root happens to be self (potentially mutated), returns None. Otherwise, returns Some(node).

pub fn remove( &mut self, db: &dyn TrieDB, path: Nibbles, ) -> Result<(Option<NodeRemoveResult>, Option<ValueRLP>), TrieError>

pub fn compute_hash(&self, crypto: &dyn Crypto) -> NodeHash

Computes the node’s hash

pub fn compute_hash_no_alloc( &self, buf: &mut Vec<u8>, crypto: &dyn Crypto, ) -> NodeHash

Computes the node’s hash, using the provided buffer

pub fn get_path( &self, db: &dyn TrieDB, path: Nibbles, node_path: &mut Vec<Vec<u8>>, ) -> Result<(), TrieError>

Traverses own subtrie until reaching the node containing path Appends all encoded nodes traversed to node_path (including self) Only nodes with encoded len over or equal to 32 bytes are included

pub fn take(&mut self) -> Self

Creates a new node by emptying self prefix and cloning the child ref

This is a way to “consume” the node when we just have a mutable reference to it