pub struct LeafNode {
pub partial: Nibbles,
pub value: ValueRLP,
}Expand description
Leaf Node of an an Ethereum Compatible Patricia Merkle Trie Contains the node’s hash, value & path
Fields
partial: Nibblesvalue: ValueRLPImplementations
Sourceimpl LeafNode
impl LeafNode
Sourcepub const fn new(partial: Nibbles, value: ValueRLP) -> Self
pub const fn new(partial: Nibbles, value: ValueRLP) -> Self
Creates a new leaf node and stores the given (path, value) pair
Sourcepub fn get(&self, path: Nibbles) -> Result<Option<ValueRLP>, TrieError>
pub fn get(&self, path: Nibbles) -> Result<Option<ValueRLP>, TrieError>
Returns the stored value if the given path matches the stored path
Sourcepub fn insert(
&mut self,
path: Nibbles,
value: ValueOrHash,
) -> Result<Option<Node>, TrieError>
pub fn insert( &mut self, path: Nibbles, value: ValueOrHash, ) -> Result<Option<Node>, TrieError>
Stores the received value and returns the new root of the subtrie previously consisting of self
Sourcepub fn remove(
&mut self,
path: Nibbles,
) -> Result<(Option<NodeRemoveResult>, Option<ValueRLP>), TrieError>
pub fn remove( &mut self, path: Nibbles, ) -> Result<(Option<NodeRemoveResult>, Option<ValueRLP>), TrieError>
Removes own value if the path matches own path and returns self and the value if it was removed
Sourcepub fn compute_hash(&self, crypto: &dyn Crypto) -> NodeHash
pub fn compute_hash(&self, crypto: &dyn Crypto) -> NodeHash
Computes the node’s hash
Sourcepub fn compute_hash_no_alloc(
&self,
buf: &mut Vec<u8>,
crypto: &dyn Crypto,
) -> NodeHash
pub fn compute_hash_no_alloc( &self, buf: &mut Vec<u8>, crypto: &dyn Crypto, ) -> NodeHash
Computes the node’s hash, using the provided buffer