pub struct Nibbles { /* private fields */ }Expand description
Struct representing a list of nibbles (half-bytes)
Implementations
Sourceimpl Nibbles
impl Nibbles
Sourcepub fn from_bytes(bytes: &[u8]) -> Self
pub fn from_bytes(bytes: &[u8]) -> Self
Splits incoming bytes into nibbles and appends the leaf flag (a 16 nibble at the end)
Sourcepub fn from_raw(bytes: &[u8], is_leaf: bool) -> Self
pub fn from_raw(bytes: &[u8], is_leaf: bool) -> Self
Splits incoming bytes into nibbles and appends the leaf flag (a 16 nibble at the end) if is_leaf is true
pub fn into_vec(self) -> Vec<u8> ⓘ
Sourcepub fn skip_prefix(&mut self, prefix: &Nibbles) -> bool
pub fn skip_prefix(&mut self, prefix: &Nibbles) -> bool
If prefix is a prefix of self, move the offset after
the prefix and return true, otherwise return false.
Sourcepub fn compare_prefix(&self, prefix: &Nibbles) -> Ordering
pub fn compare_prefix(&self, prefix: &Nibbles) -> Ordering
Compares self to another, comparing prefixes only in case of unequal lengths.
Sourcepub fn count_prefix(&self, other: &Nibbles) -> usize
pub fn count_prefix(&self, other: &Nibbles) -> usize
Compares self to another and returns the shared nibble count (amount of nibbles that are equal, from the start)
Sourcepub fn next_choice(&mut self) -> Option<usize>
pub fn next_choice(&mut self) -> Option<usize>
Removes and returns the first nibble if it is a suitable choice index (aka < 16)
Sourcepub fn slice(&self, start: usize, end: usize) -> Nibbles
pub fn slice(&self, start: usize, end: usize) -> Nibbles
Returns the nibbles beween the start and end indexes
Sourcepub fn at(&self, i: usize) -> usize
pub fn at(&self, i: usize) -> usize
Return the nibble at the given index, will panic if the index is out of range
Sourcepub fn encode_compact(&self) -> Vec<u8> ⓘ
pub fn encode_compact(&self) -> Vec<u8> ⓘ
Taken from https://github.com/citahub/cita_trie/blob/master/src/nibbles.rs#L56 Encodes the nibbles in compact form
Sourcepub fn decode_compact(compact: &[u8]) -> Self
pub fn decode_compact(compact: &[u8]) -> Self
Encodes the nibbles in compact form
Sourcepub fn is_leaf(&self) -> bool
pub fn is_leaf(&self) -> bool
Returns true if the nibbles contain the leaf flag (16) at the end
Sourcepub fn to_bytes(&self) -> Vec<u8> ⓘ
pub fn to_bytes(&self) -> Vec<u8> ⓘ
Combines the nibbles into bytes, trimming the leaf flag if necessary
Sourcepub fn concat(&self, other: &Nibbles) -> Nibbles
pub fn concat(&self, other: &Nibbles) -> Nibbles
Concatenates self and another Nibbles returning a new Nibbles
Sourcepub fn append_new(&self, nibble: u8) -> Nibbles
pub fn append_new(&self, nibble: u8) -> Nibbles
Returns a copy of self with the nibble added at the end