pub enum TrieGenerationError {
IndexNotFound(Nibbles),
TrieStackEmpty(Nibbles),
FlushToDbError(TrieError),
ThreadJoinError(),
}Expand description
These errors should never happen on a correctly ordered list, but they can happen if the iterator used as input has repeated or out of order values
Variants