Re-exports
pub use self::db::InMemoryTrieDB;pub use self::db::TrieDB;pub use self::logger::TrieLogger;pub use self::logger::TrieWitness;pub use self::threadpool::ThreadPool;pub use self::node::Node;pub use self::node::NodeRef;pub use self::error::ExtensionNodeErrorData;pub use self::error::InconsistentTreeError;pub use self::error::TrieError;
Modules
Structs
- EMPTY_
TRIE_ HASH - Nibbles
- Struct representing a list of nibbles (half-bytes)
- Proof
Trie - Trie
- Ethereum-compatible Merkle Patricia Trie
Enums
- Node
Hash - Struct representing a trie node hash If the encoded node is less than 32 bits, contains the encoded node itself
Functions
- verify_
range - Verifies that the key value range belongs to the trie with the given root given the edge proofs for the range Also returns true if there is more state to be fetched (aka if there are more keys to the right of the given range)