pub fn verify_range(
root: H256,
left_bound: &H256,
keys: &[H256],
values: &[ValueRLP],
proof: &[Vec<u8>],
) -> Result<bool, TrieError>Expand description
Verifies that the key value range belongs to the trie with the given root given the edge proofs for the range Also returns true if there is more state to be fetched (aka if there are more keys to the right of the given range)