Skip to main contentModule node
Source - BranchNode
- Branch Node of an an Ethereum Compatible Patricia Merkle Trie
Contains the node’s value and the hash of its children nodes
- ExtensionNode
- Extension Node of an an Ethereum Compatible Patricia Merkle Trie
Contains the node’s prefix and a its child node hash, doesn’t store any value
- LeafNode
- Leaf Node of an an Ethereum Compatible Patricia Merkle Trie
Contains the node’s hash, value & path
- ArchivedNode
- An archived
Node - ArchivedNodeRef
- An archived
NodeRef - Node
- A Node in an Ethereum Compatible Patricia Merkle Trie
- NodeRef
- A reference to a node.
- NodeRefResolver
- The resolver for an archived
NodeRef - NodeRemoveResult
- Used as return type for
Node remove operations that may resolve into either: - NodeResolver
- The resolver for an archived
Node - ValueOrHash