Nibbles

Struct Nibbles 

pub struct Nibbles { /* private fields */ }
Struct representing a list of nibbles (half-bytes)

Implementations

Source

impl Nibbles

pub const fn from_hex(hex: Vec<u8>) -> Self

Create Nibbles from hex-encoded nibbles

pub fn from_bytes(bytes: &[u8]) -> Self

Splits incoming bytes into nibbles and appends the leaf flag (a 16 nibble at the end)

pub fn from_raw(bytes: &[u8], is_leaf: bool) -> Self

Splits incoming bytes into nibbles and appends the leaf flag (a 16 nibble at the end) if is_leaf is true

pub fn into_vec(self) -> Vec<u8>

pub fn len(&self) -> usize

Returns the amount of nibbles

pub fn is_empty(&self) -> bool

Returns true if there are no nibbles

pub fn skip_prefix(&mut self, prefix: &Nibbles) -> bool

If prefix is a prefix of self, move the offset after the prefix and return true, otherwise return false.

pub fn compare_prefix(&self, prefix: &Nibbles) -> Ordering

Compares self to another, comparing prefixes only in case of unequal lengths.

pub fn count_prefix(&self, other: &Nibbles) -> usize

Compares self to another and returns the shared nibble count (amount of nibbles that are equal, from the start)

pub fn next(&mut self) -> Option<u8>

Removes and returns the first nibble

pub fn next_choice(&mut self) -> Option<usize>

Removes and returns the first nibble if it is a suitable choice index (aka < 16)

pub fn offset(&self, offset: usize) -> Nibbles

Returns the nibbles after the given offset

pub fn slice(&self, start: usize, end: usize) -> Nibbles

Returns the nibbles beween the start and end indexes

pub fn extend(&mut self, other: &Nibbles)

Extends the nibbles with another list of nibbles

pub fn at(&self, i: usize) -> usize

Return the nibble at the given index, will panic if the index is out of range

pub fn prepend(&mut self, nibble: u8)

Inserts a nibble at the start

pub fn append(&mut self, nibble: u8)

Inserts a nibble at the end

pub fn encode_compact(&self) -> Vec<u8>

Taken from https://github.com/citahub/cita_trie/blob/master/src/nibbles.rs#L56 Encodes the nibbles in compact form

pub fn decode_compact(compact: &[u8]) -> Self

Encodes the nibbles in compact form

pub fn is_leaf(&self) -> bool

Returns true if the nibbles contain the leaf flag (16) at the end

pub fn to_bytes(&self) -> Vec<u8>

Combines the nibbles into bytes, trimming the leaf flag if necessary

pub fn concat(&self, other: &Nibbles) -> Nibbles

Concatenates self and another Nibbles returning a new Nibbles

pub fn append_new(&self, nibble: u8) -> Nibbles

Returns a copy of self with the nibble added at the end

pub fn current(&self) -> Nibbles

Return already consumed parts of path

pub fn take(&mut self) -> Self

Empties self.data and returns the content